# foran

In front or behind (Danish: foran eller bagved)? Answering the question if a local repository status is in front of or behind its remote.

[License: MIT](https://git.sr.ht/~sthagen/foran/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/foran.svg?style=flat)](https://pypi.python.org/pypi/foran/)
[![downloads](https://pepy.tech/badge/foran/month)](https://pepy.tech/project/foran)
[![wheel](https://img.shields.io/pypi/wheel/foran.svg?style=flat)](https://pypi.python.org/pypi/foran/)
[![supported-versions](https://img.shields.io/pypi/pyversions/foran.svg?style=flat)](https://pypi.python.org/pypi/foran/)
[![supported-implementations](https://img.shields.io/pypi/implementation/foran.svg?style=flat)](https://pypi.python.org/pypi/foran/)

The English "in front" may translate to the Danish "foran".

... and the default report stem `foran-eller-bagved` alludes to the English "In front or behind?" question which corresponds to the Danish "Foran eller bagved?"

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of foran](https://todo.sr.ht/~sthagen/foran).

## Primary Source repository

The primary source of `foran` lives somewhere on a mountain in Central Switzerland.
But, we use decentralized version control (git), so any clone can become the source to everyone's benefit, no central only code.
Anyway, the preferred public clones of `foran` are:

* [on codeberg](https://codeberg.org/sthagen/foran) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/foran) - a collection of tools useful for software development.
